@@ -1,4 +1,5 @@
 from argparse import ArgumentParser, Namespace
+from datetime import datetime
 from hashlib import sha1
 from os import R_OK, access
 from os.path import basename, dirname, join
@@ -20,23 +21,31 @@ def parse_args() -> Namespace:
     parser = ArgumentParser()
 
     parser.add_argument("markdown")
-    parser.add_argument("--stdin", action="store_true")
-    parser.add_argument("-p", "--port", type=int, default=8080)
-    parser.add_argument("-o", "--open", action="store_true")
-    parser.add_argument("-n", "--no-follow", dest="follow", action="store_false")
 
+    location = parser.add_argument_group()
+    location.add_argument("-p", "--port", type=int, default=8080)
+    location.add_argument("-o", "--open", action="store_true")
+
+    behaviour = parser.add_argument_group()
+    behaviour.add_argument("--nf", "--no-follow", dest="follow", action="store_false")
+    behaviour.add_argument("--nb", "--no-browser", dest="browser", action="store_false")
+
+    internal = parser.add_argument_group()
+    internal.add_argument(
+        "--read-stdin", action="store_true", help="INTERNAL USE ONLY"
+    )
     return parser.parse_args()
 
 
 async def main() -> None:
     args = parse_args()
 
-    if (not args.stdin) and (not access(args.markdown, R_OK)):
+    if (not args.read_stdin) and (not access(args.markdown, R_OK)):
         print(f"cannot read -- {args.markdown}", file=stderr)
         exit(1)
 
     render_f = await render()
-    watch_f = stream if args.stdin else watch
+    watch_f = stream if args.read_stdin else watch
 
     name = basename(args.markdown)
     cached, markdown = None, ""
@@ -56,6 +65,8 @@ async def main() -> None:
             cached, markdown = reconciliate(cached, xhtml)
             sha = sha1(markdown.encode()).hexdigest()
             yield
+            time = datetime.now().strftime("%H:%M:%S")
+            print(f"🦑 -- {time}")
 
     serve = build(
         localhost=not args.open,
@@ -68,7 +79,8 @@ async def main() -> None:
     async def post() -> None:
         host = getfqdn() if args.open else "localhost"
         uri = f"http://{host}:{args.port}"
-        open_w(uri)
+        if args.browser:
+            open_w(uri)
         print(f"SERVING -- {uri}")
 
     await serve(post)
